@@ -10,7 +10,7 @@ use WebService::SSLLabs::Host();
 use WebService::SSLLabs::Endpoint();
 use WebService::SSLLabs::StatusCodes();
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 sub new {
     my ($class) = @_;
@@ -130,7 +130,7 @@ WebService::SSLLabs - Analyze the configuration of any SSL web server on the pub
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SYNOPSIS
 
@@ -144,9 +144,15 @@ Check the security of your TLS services
         sleep 10;
     }
     if ($host->ready()) {
-       foreach my $endpoint ($host->endpoints()) {
-           say $host->host() . ' at ' . $endpoint->ip_address() . ' gets a ' . $endpoint->grade();
-       }
+        foreach my $endpoint ($host->endpoints()) {
+           if ($endpoint->ready()) {
+              say $host->host() . ' at ' . $endpoint->ip_address() . ' gets a ' . $endpoint->grade();
+           } else {
+              warn $host->host() . ' at ' . $endpoint->ip_address() . ' returned an error:' . $endpoint->status_message();
+           }  
+        }
+    } else {
+        warn $host->host() . ' returned an error:' . $host->status_message();
     }
 
 =head1 DESCRIPTION
