@@ -4,16 +4,22 @@ use strict;
 use warnings;
 use WebService::SSLLabs::ChainCert();
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 sub new {
     my ( $class, $json ) = @_;
     my $self = $json;
     bless $self, $class;
-    my @certs = @{ $self->{certs} };
-    $self->{certs} = [];
-    foreach my $cert (@certs) {
-        push @{ $self->{certs} }, WebService::SSLLabs::ChainCert->new($cert);
+    if ( defined $self->{certs} ) {
+        my @certs = @{ $self->{certs} };
+        $self->{certs} = [];
+        foreach my $cert (@certs) {
+            push @{ $self->{certs} },
+              WebService::SSLLabs::ChainCert->new($cert);
+        }
+    }
+    else {
+        $self->{certs} = [];
     }
     return $self;
 }
@@ -37,7 +43,7 @@ WebService::SSLLabs::Chain - Chain object
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SUBROUTINES/METHODS
 
