@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::EndpointDetails();
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -17,6 +17,18 @@ sub new {
     return $self;
 }
 
+sub ready {
+    my ($self) = @_;
+    if ( defined $self->{statusMessage}
+        && $self->{statusMessage} =~ /^READY$/ismx )
+    {
+        return $self;
+    }
+    else {
+        return;
+    }
+}
+
 sub ip_address {
     my ($self) = @_;
     return $self->{ipAddress};
@@ -86,7 +98,7 @@ WebService::SSLLabs::Endpoint - Endpoint object
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SUBROUTINES/METHODS
 
@@ -94,6 +106,10 @@ Version 0.14
 
 a new C<WebService::SSLLabs::Endpoint> object, accepts a hash ref as it's parameter.
 
+=head2 ready
+
+will return the current C<WebService::SSLLabs::Endpoint> object if L<status|WebService::SSLLabs::Endpoint/"status_message"> is equal to Ready.  Otherwise it will return undef.
+
 =head2 subject
 
 certificate subject
