@@ -4,16 +4,21 @@ use strict;
 use warnings;
 use WebService::SSLLabs::Endpoint();
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 sub new {
     my ( $class, $json ) = @_;
-    my $self      = $json;
-    my @endpoints = @{ $self->{endpoints} };
-    $self->{endpoints} = [];
-    foreach my $endpoint (@endpoints) {
-        push @{ $self->{endpoints} },
-          WebService::SSLLabs::Endpoint->new($endpoint);
+    my $self = $json;
+    if ( defined $self->{endpoints} ) {
+        my @endpoints = @{ $self->{endpoints} };
+        $self->{endpoints} = [];
+        foreach my $endpoint (@endpoints) {
+            push @{ $self->{endpoints} },
+              WebService::SSLLabs::Endpoint->new($endpoint);
+        }
+    }
+    else {
+        $self->{endpoints} = [];
     }
     bless $self, $class;
     return $self;
@@ -103,7 +108,7 @@ WebService::SSLLabs::Host - Host object
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SUBROUTINES/METHODS
 
@@ -154,7 +159,7 @@ assessment completion time, in milliseconds since 1970
 
 =head2 engine_version
 
-assessment engine version (e.g., "1.0.140")
+assessment engine version (e.g., "1.0.150")
 
 =head2 criteria_version
 
