@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::Simulation();
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -13,7 +13,8 @@ sub new {
     my @simulations = @{ $self->{results} };
     $self->{results} = [];
     foreach my $simulation (@simulations) {
-        push @{ $self->{results} }, WebService::SSLLabs::Simulation->new($simulation);
+        push @{ $self->{results} },
+          WebService::SSLLabs::Simulation->new($simulation);
     }
     return $self;
 }
@@ -32,7 +33,7 @@ WebService::SSLLabs::SimDetails - SimDetails object
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SUBROUTINES/METHODS
 
