@@ -4,16 +4,21 @@ use strict;
 use warnings;
 use WebService::SSLLabs::Suite();
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 sub new {
     my ( $class, $json ) = @_;
     my $self = $json;
     bless $self, $class;
-    my @suites = @{ $self->{list} };
-    $self->{list} = [];
-    foreach my $suite (@suites) {
-        push @{ $self->{list} }, WebService::SSLLabs::Suite->new($suite);
+    if ( defined $self->{list} ) {
+        my @suites = @{ $self->{list} };
+        $self->{list} = [];
+        foreach my $suite (@suites) {
+            push @{ $self->{list} }, WebService::SSLLabs::Suite->new($suite);
+        }
+    }
+    else {
+        $self->{list} = [];
     }
     return $self;
 }
@@ -37,7 +42,7 @@ WebService::SSLLabs::Suites - Suites object
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SUBROUTINES/METHODS
 
